==> react-bootstrap-0.2.0.tgz: package/es/components/PopupWithCard/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { Fragment } from 'react';
import PropTypes from 'prop-types';

import Button from '../Button';
import Card from '../Card';
import Icon from '../Icon';
import Popup from '../Popup';

import colors from '../../utils/colors';

var PopupWithCard = function PopupWithCard(_ref) {
  var color = _ref.color,
      title = _ref.title,
      controls = _ref.controls,
      closeButtonTitle = _ref.closeButtonTitle,
      onClose = _ref.onClose,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['color', 'title', 'controls', 'closeButtonTitle', 'onClose', 'children']);

  return React.createElement(
    Popup,
    { closeButtonTitle: closeButtonTitle, onClose: onClose },
    React.createElement(
      Card,
      _extends({
        color: color,
        title: title,
        collapsible: false,
        controls: title || controls ? React.createElement(
          Fragment,
          null,
          typeof controls === 'string' ? React.createElement(
            'div',
            null,
            controls
          ) : controls,
          React.createElement(
            Button,
            {
              color: color || 'light',
              className: 'ml-3',
              onClick: onClose,
              title: closeButtonTitle
            },
            React.createElement(Icon, { name: 'close' })
          )
        ) : null
      }, props),
      children
    )
  );
};

PopupWithCard.propTypes = process.env.NODE_ENV !== "production" ? {
  color: PropTypes.oneOf([].concat(colors, [''])),
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  controls: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  closeButtonTitle: PropTypes.string,
  onClose: PropTypes.func,
  children: PropTypes.node
} : {};

PopupWithCard.defaultProps = {
  color: '',
  title: null,
  controls: null,
  closeButtonTitle: 'Close',
  onClose: function onClose() {},
  children: null
};

export default PopupWithCard;

==> react-bootstrap-0.3.0.tgz: package/es/components/PopupWithCard/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { Fragment } from 'react';
import PropTypes from 'prop-types';

import Button from '../Button';
import Card from '../Card';
import Icon from '../Icon';
import Popup from '../Popup';

import colors from '../../utils/colors';

var PopupWithCard = function PopupWithCard(_ref) {
  var color = _ref.color,
      title = _ref.title,
      controls = _ref.controls,
      closeButtonTitle = _ref.closeButtonTitle,
      onClose = _ref.onClose,
      props = _objectWithoutProperties(_ref, ['color', 'title', 'controls', 'closeButtonTitle', 'onClose']);

  return React.createElement(
    Popup,
    { closeButtonTitle: closeButtonTitle, onClose: onClose },
    React.createElement(Card, _extends({
      color: color,
      title: title,
      collapsible: false,
      controls: title || controls ? React.createElement(
        Fragment,
        null,
        typeof controls === 'string' ? React.createElement(
          'div',
          null,
          controls
        ) : controls,
        React.createElement(
          Button,
          {
            color: color || 'light',
            className: 'ml-3',
            onClick: onClose,
            title: closeButtonTitle
          },
          React.createElement(Icon, { name: 'close' })
        )
      ) : null
    }, props))
  );
};

PopupWithCard.propTypes = process.env.NODE_ENV !== "production" ? {
  color: PropTypes.oneOf([].concat(colors, [''])),
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  controls: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  closeButtonTitle: PropTypes.string,
  onClose: PropTypes.func
} : {};

PopupWithCard.defaultProps = {
  color: '',
  title: null,
  controls: null,
  closeButtonTitle: 'Close',
  onClose: function onClose() {}
};

export default PopupWithCard;
